schema_sentinel.metadata_manager.changeset API documentation

# schema_sentinel.metadata_manager.changeset

View Source

     1class ChangeSet:
     2    def __init__(
     3        self,
     4        id,
     5        author,
     6        file_name,
     7        run_manually=False,
     8        depends_on=None,
     9        md5sum=None,
    10        date_executed=None,
    11        index=0,
    12        contexts=None,
    13        approved_by=None,
    14        jira_ticket=None,
    15        jira_description=None,
    16        tag=None,
    17        description=None,
    18        run_always=False,
    19    ):
    20        self.id = id
    21        self.author = author
    22        self.file_name = file_name
    23        self.run_manually = run_manually
    24        self.depends_on = depends_on
    25        self.md5sum = md5sum
    26        self.date_executed = date_executed
    27        self.index = index
    28        self.contexts = contexts
    29        self.approved_by = approved_by
    30        self.jira_ticket = jira_ticket
    31        self.jira_description = jira_description
    32        self.tag = tag
    33        self.description = description
    34        self.run_always = run_always
    35
    36    def __iter__(self):
    37        yield self
    38
    39    def to_string(self):
    40        return self.__dict__

class ChangeSet: View Source

     2class ChangeSet:
     3    def __init__(
     4        self,
     5        id,
     6        author,
     7        file_name,
     8        run_manually=False,
     9        depends_on=None,
    10        md5sum=None,
    11        date_executed=None,
    12        index=0,
    13        contexts=None,
    14        approved_by=None,
    15        jira_ticket=None,
    16        jira_description=None,
    17        tag=None,
    18        description=None,
    19        run_always=False,
    20    ):
    21        self.id = id
    22        self.author = author
    23        self.file_name = file_name
    24        self.run_manually = run_manually
    25        self.depends_on = depends_on
    26        self.md5sum = md5sum
    27        self.date_executed = date_executed
    28        self.index = index
    29        self.contexts = contexts
    30        self.approved_by = approved_by
    31        self.jira_ticket = jira_ticket
    32        self.jira_description = jira_description
    33        self.tag = tag
    34        self.description = description
    35        self.run_always = run_always
    36
    37    def __iter__(self):
    38        yield self
    39
    40    def to_string(self):
    41        return self.__dict__

ChangeSet( id, author, file_name, run_manually=False, depends_on=None, md5sum=None, date_executed=None, index=0, contexts=None, approved_by=None, jira_ticket=None, jira_description=None, tag=None, description=None, run_always=False) View Source

     3    def __init__(
     4        self,
     5        id,
     6        author,
     7        file_name,
     8        run_manually=False,
     9        depends_on=None,
    10        md5sum=None,
    11        date_executed=None,
    12        index=0,
    13        contexts=None,
    14        approved_by=None,
    15        jira_ticket=None,
    16        jira_description=None,
    17        tag=None,
    18        description=None,
    19        run_always=False,
    20    ):
    21        self.id = id
    22        self.author = author
    23        self.file_name = file_name
    24        self.run_manually = run_manually
    25        self.depends_on = depends_on
    26        self.md5sum = md5sum
    27        self.date_executed = date_executed
    28        self.index = index
    29        self.contexts = contexts
    30        self.approved_by = approved_by
    31        self.jira_ticket = jira_ticket
    32        self.jira_description = jira_description
    33        self.tag = tag
    34        self.description = description
    35        self.run_always = run_always

id
author
file_name
run_manually
depends_on
md5sum
date_executed
index
contexts
approved_by
jira_ticket
jira_description
tag
description
run_always
def to_string(self): View Source

    40    def to_string(self):
    41        return self.__dict__